From mboxrd@z Thu Jan  1 00:00:00 1970
From: Klemens Nanni <klemens@posteo.de>
To: list+catgirl@causal.agency
Cc: Klemens Nanni <klemens@posteo.de>
Subject: [PATCH] OpenBSD: Simplify promise creation after seprintf() introduction
Date: Mon, 14 Jun 2021 21:37:07 +0000
Message-Id: <20210614213707.30406-1-klemens@posteo.de>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

Just truncate the initial promises back to the final ones after pledging
for the first time, saving code and memory.

Assign `ptr' in all initial `seprintf()' calls for consistency while
here.
---
 chat.c | 9 ++++-----
 1 file changed, 4 insertions(+), 5 deletions(-)

diff --git a/chat.c b/chat.c
index 2a64ee0..9332ca8 100644
--- a/chat.c
+++ b/chat.c
@@ -295,10 +295,9 @@ int main(int argc, char *argv[]) {
 	if (logEnable) ptr = seprintf(ptr, end, " wpath cpath");
 	if (!self.restricted) ptr = seprintf(ptr, end, " proc exec");
 
-	char *promisesFinal = strdup(promises);
-	if (!promisesFinal) err(EX_OSERR, "strdup");
+	char *promisesInitial = ptr;
 
-	seprintf(ptr, end, " inet dns");
+	ptr = seprintf(ptr, end, " inet dns");
 	int error = pledge(promises, NULL);
 	if (error) err(EX_OSERR, "pledge");
 #endif
@@ -316,9 +315,9 @@ int main(int argc, char *argv[]) {
 	int irc = ircConnect(bind, host, port);
 
 #ifdef __OpenBSD__
-	error = pledge(promisesFinal, NULL);
+	*promisesInitial = '\0';
+	error = pledge(promises, NULL);
 	if (error) err(EX_OSERR, "pledge");
-	free(promisesFinal);
 #endif
 
 	if (pass) ircFormat("PASS :%s\r\n", pass);
-- 
2.32.0


